mathtools.BoundedObject
=======================

.. abjad-lineage:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject

.. autoclass:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_closed
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_half_closed
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_half_open
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_open
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_left_closed
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_left_open
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_right_closed
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_right_open
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__ge__
   :noindex:

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__gt__
   :noindex:

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__le__
   :noindex:

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__lt__
   :noindex:

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__repr__
   :noindex:
